@@ -21,16 +21,15 @@ from queue import Queue, Full
 from threading import Thread, Event
 from typing import TYPE_CHECKING
 
-from skywalking.protocol.logging.Logging_pb2 import LogData
-
 from skywalking import config, plugins
 from skywalking import loggings
+from skywalking import profile
 from skywalking.agent.protocol import Protocol
 from skywalking.command import command_service
 from skywalking.loggings import logger
-from skywalking import profile
 from skywalking.profile.profile_task import ProfileTask
 from skywalking.profile.snapshot import TracingThreadSnapshot
+from skywalking.protocol.logging.Logging_pb2 import LogData
 
 if TYPE_CHECKING:
     from skywalking.trace.context import Segment
@@ -124,7 +123,7 @@ def __init_threading():
     __finished = Event()
     __heartbeat_thread = Thread(name='HeartbeatThread', target=__heartbeat, daemon=True)
     __report_thread = Thread(name='ReportThread', target=__report, daemon=True)
-    __command_dispatch_thread = Thread(name="CommandDispatchThread", target=__command_dispatch, daemon=True)
+    __command_dispatch_thread = Thread(name='CommandDispatchThread', target=__command_dispatch, daemon=True)
 
     __heartbeat_thread.start()
     __report_thread.start()
@@ -153,7 +152,7 @@ def __init():
     elif config.protocol == 'http':
         from skywalking.agent.protocol.http import HttpProtocol
         __protocol = HttpProtocol()
-    elif config.protocol == "kafka":
+    elif config.protocol == 'kafka':
         from skywalking.agent.protocol.kafka import KafkaProtocol
         __protocol = KafkaProtocol()
 
@@ -182,7 +181,7 @@ def __fini():
 
 def __fork_before():
     if config.protocol != 'http':
-        logger.warning('fork() not currently supported with %s protocol' % config.protocol)
+        logger.warning(f'fork() not currently supported with {config.protocol} protocol')
 
     # TODO: handle __queue and __finished correctly (locks, mutexes, etc...), need to lock before fork and unlock after
     # if possible, or ensure they are not locked in threads (end threads and restart after fork?)
@@ -208,7 +207,7 @@ def start():
     flag = False
     try:
         from gevent import monkey
-        flag = monkey.is_module_patched("socket")
+        flag = monkey.is_module_patched('socket')
     except ModuleNotFoundError:
         logger.debug("it was found that no gevent was used, if you don't use, please ignore.")
     if flag:
@@ -266,4 +265,4 @@ def notify_profile_finish(task: ProfileTask):
     try:
         __protocol.notify_profile_task_finish(task)
     except Exception as e:
-        logger.error("notify profile task finish to backend fail. " + str(e))
+        logger.error(f'notify profile task finish to backend fail. {str(e)}')
