@@ -18,21 +18,21 @@
 import ast
 import os
 
-from skywalking.protocol.common.Common_pb2 import KeyStringValuePair
-from skywalking.protocol.management.Management_pb2 import InstancePingPkg, InstanceProperties
-
 from kafka import KafkaProducer
+
 from skywalking import config
 from skywalking.client import ServiceManagementClient, TraceSegmentReportService, LogDataReportService
-from skywalking.loggings import logger
+from skywalking.loggings import logger, logger_debug_enabled
+from skywalking.protocol.common.Common_pb2 import KeyStringValuePair
+from skywalking.protocol.management.Management_pb2 import InstancePingPkg, InstanceProperties
 
 kafka_configs = {}
 
 
 def __init_kafka_configs():
-    kafka_configs["bootstrap_servers"] = config.kafka_bootstrap_servers.split(",")
+    kafka_configs['bootstrap_servers'] = config.kafka_bootstrap_servers.split(',')
     # process all kafka configs in env
-    kafka_keys = [key for key in os.environ.keys() if key.startswith("SW_KAFKA_REPORTER_CONFIG_")]
+    kafka_keys = [key for key in os.environ.keys() if key.startswith('SW_KAFKA_REPORTER_CONFIG_')]
     for kafka_key in kafka_keys:
         key = kafka_key[25:]
         val = os.environ.get(kafka_key)
@@ -40,7 +40,7 @@ def __init_kafka_configs():
         if val is not None:
             if val.isnumeric():
                 val = int(val)
-            elif val in ["True", "False"]:
+            elif val in ['True', 'False']:
                 val = ast.literal_eval(val)
         else:
             continue
@@ -57,18 +57,25 @@ __init_kafka_configs()
 
 class KafkaServiceManagementClient(ServiceManagementClient):
     def __init__(self):
-        logger.debug("kafka reporter configs: %s", kafka_configs)
+        if logger_debug_enabled:
+            logger.debug('kafka reporter configs: %s', kafka_configs)
         self.producer = KafkaProducer(**kafka_configs)
-        self.topic_key_register = "register-"
+        self.topic_key_register = 'register-'
         self.topic = config.kafka_topic_management
 
         self.send_instance_props()
 
     def send_instance_props(self):
+        properties = [
+            KeyStringValuePair(key='language', value='python'),
+            KeyStringValuePair(key='Process No.', value=str(os.getpid())),
+        ]
+        if config.agent_namespace:
+            properties.append(KeyStringValuePair(key='namespace', value=config.agent_namespace))
         instance = InstanceProperties(
             service=config.service_name,
             serviceInstance=config.service_instance,
-            properties=[KeyStringValuePair(key='language', value='Python')],
+            properties=properties,
         )
 
         key = bytes(self.topic_key_register + instance.serviceInstance, encoding='utf-8')
@@ -76,22 +83,24 @@ class KafkaServiceManagementClient(ServiceManagementClient):
         self.producer.send(topic=self.topic, key=key, value=value)
 
     def send_heart_beat(self):
-        logger.debug(
-            'service heart beats, [%s], [%s]',
-            config.service_name,
-            config.service_instance,
-        )
+        if logger_debug_enabled:
+            logger.debug(
+                'service heart beats, [%s], [%s]',
+                config.service_name,
+                config.service_instance,
+            )
 
         instance_ping_pkg = InstancePingPkg(
             service=config.service_name,
             serviceInstance=config.service_instance,
         )
 
-        key = bytes(instance_ping_pkg.serviceInstance, encoding="utf-8")
+        key = bytes(instance_ping_pkg.serviceInstance, encoding='utf-8')
         value = bytes(instance_ping_pkg.SerializeToString())
         future = self.producer.send(topic=self.topic, key=key, value=value)
         res = future.get(timeout=10)
-        logger.debug('heartbeat response: %s', res)
+        if logger_debug_enabled:
+            logger.debug('heartbeat response: %s', res)
 
 
 class KafkaTraceSegmentReportService(TraceSegmentReportService):
@@ -101,7 +110,7 @@ class KafkaTraceSegmentReportService(TraceSegmentReportService):
 
     def report(self, generator):
         for segment in generator:
-            key = bytes(segment.traceSegmentId, encoding="utf-8")
+            key = bytes(segment.traceSegmentId, encoding='utf-8')
             value = bytes(segment.SerializeToString())
             self.producer.send(topic=self.topic, key=key, value=value)
 
@@ -113,7 +122,7 @@ class KafkaLogDataReportService(LogDataReportService):
 
     def report(self, generator):
         for log_data in generator:
-            key = bytes(log_data.traceContext.traceSegmentId, encoding="utf-8")
+            key = bytes(log_data.traceContext.traceSegmentId, encoding='utf-8')
             value = bytes(log_data.SerializeToString())
             self.producer.send(topic=self.topic, key=key, value=value)
 
