@@ -27,7 +27,7 @@ def sw_urlparse(url):
     url_param = urlparse(url)
     safe_netloc = url_param.netloc
     try:
-        safe_netloc = str(url_param.hostname) + (':' + str(url_param.port) if url_param.port else '')
+        safe_netloc = f"{url_param.hostname}{f':{str(url_param.port)}' if url_param.port else ''}"
     except ValueError:  # illegal url, skip
         pass
 
@@ -36,8 +36,10 @@ def sw_urlparse(url):
 
 def sw_filter(target: str):
     # Remove user:pw from any valid full urls
-
-    return re.sub(r'://(.*?)@', r'://', target)
+    # this filter is disabled by default due to perf impact
+    if config.log_reporter_safe_mode:
+        return re.sub(r'://(.*?)@', r'://', target)
+    return target
 
 
 def sw_traceback():
